import { EvaEndpoint, IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { GetRecoilValue, RecoilState, RecoilValueReadOnly, SerializableParam } from 'recoil';
export interface IServiceFamilyState<SVC extends IEvaServiceDefinition> {
    error: (parameter: SerializableParam) => RecoilValueReadOnly<Error | undefined>;
    request: (parameter: SerializableParam) => RecoilState<SVC['request']>;
    response: (parameter: SerializableParam) => RecoilValueReadOnly<SVC['response']>;
    responseRaw: (parameter: SerializableParam) => RecoilValueReadOnly<SVC['response'] | Error | undefined>;
    stale: (parameter: SerializableParam) => RecoilState<string>;
}
/**
 * Build the state values for an EVA service call with a family selector.
 * The service request is used as the family key.
 * As a bare minimum you need to supply the service definition from the SDK and
 * the service request.
 *
 * The recoil `key` needs to be unique and will default to the service name.
 * If you require the same service for different use cases you must supply a
 * unique key name which should also indicate its intended purpose.
 * As a convenience you can use the `requireCustomer` and `requireEmployee`
 * flags to prevent service calls from going out depending on the current user.
 *
 * @template SVC
 * @param {{
 *     service: new () => SVC,
 *     defaultRequest?: SVC['request'],
 *     key?: string,
 *     requireCustomer?: boolean,
 *     requireEmployee?: boolean,
  *    requestedOrganizationUnitIDOverrideState?: RecoilState<number>,
 *   }} {
 *     service,
 *     defaultRequest,
 *     key,
 *     requireCustomer,
 *     requireEmployee,
 *     requestedOrganizationUnitIDOverrideState,
 *   }
 * @returns {IServiceState<SVC>}
 */
declare const buildServiceFamilyState: <SVC extends IEvaServiceDefinition>({ allowEmptyRequest, service, defaultRequest, key, requireCustomer, requireEmployee, requireLoggedIn, beforeRequest, customRequest, requestedOrganizationUnitIDOverrideState, }: {
    allowEmptyRequest?: boolean;
    service: new () => SVC;
    defaultRequest?: SVC['request'];
    key?: string;
    requireCustomer?: boolean;
    requireEmployee?: boolean;
    requireLoggedIn?: boolean;
    beforeRequest?: (params: {
        req: SVC['request'];
        get: GetRecoilValue;
        parameter: SerializableParam;
    }) => SVC['request'];
    customRequest?: (params: {
        endpoint: EvaEndpoint;
        payload?: SVC['request'];
        options: IEvaServiceCallOptions;
    }) => Promise<SVC['response']>;
    requestedOrganizationUnitIDOverrideState?: RecoilState<number>;
}) => IServiceFamilyState<SVC>;
export default buildServiceFamilyState;
//# sourceMappingURL=build-service-family-state.d.ts.map