import { EvaEndpoint, IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { GetRecoilValue, RecoilState, RecoilValueReadOnly } from 'recoil';
export interface IServiceState<SVC extends IEvaServiceDefinition> {
    error: RecoilValueReadOnly<Error | undefined>;
    recoilKey: string;
    request: RecoilState<SVC['request']>;
    response: RecoilValueReadOnly<SVC['response']>;
    responseRaw: RecoilValueReadOnly<SVC['response'] | Error | undefined>;
    stale: RecoilState<string>;
    storage: RecoilValueReadOnly<void>;
}
/**
 * Build the state values for an EVA service call.
 * As a bare minimum you need to supply the service definition from the SDK.
 *
 * The recoil `key` needs to be unique and will default to the service name.
 * If you require the same service for different use cases you must supply a
 * unique key name which should also indicate its intended purpose.
 * As a convenience you can use the `requireCustomer` and `requireEmployee`
 * flags to prevent service calls from going out depending on the current user.
 *
 * @template SVC
 * @param {{
 *     allowEmptyRequest?: boolean,
 *     service: new () => SVC,
 *     defaultRequest?: SVC['request'],
 *     key?: string,
 *     requireCustomer?: boolean,
 *     requireEmployee?: boolean,
 *     requireLoggedIn?: boolean,
 *     beforeRequest?: (params: { req: SVC['request'], get: GetRecoilValue }) => SVC['request'],
 *     requestedOrganizationUnitIDOverrideState: RecoilState<number>,
 *   }} {
 *     allowEmptyRequest = true,
 *     service,
 *     defaultRequest,
 *     key,
 *     requireCustomer,
 *     requireEmployee,
 *     requireLoggedIn,
 *     beforeRequest,
 *     requestedOrganizationUnitIDOverrideState,
 *   }
 * @returns {IServiceState<SVC>}
 */
declare const buildServiceState: <SVC extends IEvaServiceDefinition>({ allowEmptyRequest, service, defaultRequest, key, requireCustomer, requireEmployee, requireLoggedIn, beforeRequest, customRequest, requestedOrganizationUnitIDOverrideState, }: {
    allowEmptyRequest?: boolean;
    service: new () => SVC;
    defaultRequest?: SVC['request'];
    key?: string;
    requireCustomer?: boolean;
    requireEmployee?: boolean;
    requireLoggedIn?: boolean;
    beforeRequest?: (params: {
        req: SVC['request'];
        get: GetRecoilValue;
    }) => SVC['request'];
    customRequest?: (params: {
        endpoint: EvaEndpoint;
        payload?: SVC['request'];
        options: IEvaServiceCallOptions;
    }) => Promise<SVC['response']>;
    requestedOrganizationUnitIDOverrideState?: RecoilState<number>;
}) => IServiceState<SVC>;
export default buildServiceState;
//# sourceMappingURL=build-service-state.d.ts.map