export { IUseCallServiceOptions } from './hooks/use-call-service.js';
import * as authorizationStructure from './helpers/authorization-structure.js';
import * as createSelectors from './helpers/create-selectors.js';
import * as orderStatus from './helpers/order-status.js';
import * as productCount from './helpers/product-count-by-type.js';
export { ICreateGetterSetterSelector, ICreateGetterSetterSelectorFamily, } from './helpers/create-selectors.js';
export { IProductCountByType } from './helpers/product-count-by-type.js';
export { ICheckoutStepStatus, IOrderStatus, IPickDiscountProductState, IProductBundleState, IProductRequirementState, IProductSerialNumberState, } from './helpers/order-status.js';
export { IEvaStateStorage } from './helpers/storage.js';
export * from './settings.js';
export declare const helpers: {
    authorizationStructure: typeof authorizationStructure;
    createSelectors: typeof createSelectors;
    getEvaEndpoint: (uri: string) => Promise<import("@springtree/eva-sdk-core-service").EvaEndpoint>;
    isBundleProduct: (product: EVA.Core.GetProductDetailResponse) => boolean;
    isConfigurableProduct: (product: EVA.Core.GetProductDetailResponse) => boolean;
    orderStatus: typeof orderStatus;
    productCount: typeof productCount;
    storage: import("@springtree/eva-sdk-core-storage").EvaStorage<import("./helpers/storage.js").IEvaStateStorage>;
    userExpiration: import("./helpers/user-expiration.js").UserExpiration;
};
export declare const hooks: {
    useCallService: <SVC extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ service, }: {
        service: new () => SVC;
    }) => (requestPayload?: SVC["request"] | undefined, callOptions?: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions | undefined, hookOptions?: import("./hooks/use-call-service.js").IUseCallServiceOptions<SVC> | undefined) => Promise<SVC["response"] | undefined>;
    useDomEventListener: (eventName: string, handler: (params?: unknown) => unknown, element?: Window & typeof globalThis) => void;
    useFetchServiceOnFocus: <SVC_1 extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ serviceState, }: {
        serviceState: import("./builders/build-service-state.js").IServiceState<SVC_1> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_1>;
    }) => void;
    useGetServiceRequest: <SVC_2 extends import("@springtree/eva-services-core").IEvaServiceDefinition>(serviceState: import("./builders/build-service-state.js").IServiceState<SVC_2> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_2>, defaultValue?: SVC_2["request"] | undefined) => SVC_2["request"] | undefined;
    useGetServiceError: <SVC_3 extends import("@springtree/eva-services-core").IEvaServiceDefinition>(serviceState: import("./builders/build-service-state.js").IServiceState<SVC_3> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_3>) => Error | undefined;
    useGetServiceResponse: <SVC_4 extends import("@springtree/eva-services-core").IEvaServiceDefinition>(serviceState: import("./builders/build-service-state.js").IServiceState<SVC_4> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_4>, defaultValue?: SVC_4["response"] | undefined) => SVC_4["response"] | undefined;
    useGetState: <T = unknown>(genericState: import("recoil").RecoilValue<T>, defaultValue?: T | undefined) => T | undefined;
    useIsServiceLoading: <SVC_5 extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ serviceState, }: {
        serviceState: import("./builders/build-service-state.js").IServiceState<SVC_5> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_5>;
    }) => boolean;
    useIsLoading: <T_1 = unknown>({ state, }: {
        state: import("recoil").RecoilValue<T_1>;
    }) => boolean;
    useServiceRequestPersistence: <SVC_6 extends import("@springtree/eva-services-core").IEvaServiceDefinition>(serviceState: import("./builders/build-service-state.js").IServiceState<SVC_6>) => void;
    useSetServiceStale: <SVC_7 extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ serviceState, }: {
        serviceState: import("./builders/build-service-state.js").IServiceState<SVC_7> | import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC_7>;
    }) => () => void;
    useSetStale: ({ staleState, }: {
        staleState: import("recoil").RecoilState<string>;
    }) => () => void;
    useShoppingCartAdd: <SVC_8 extends import("@springtree/eva-services-core").IEvaServiceDefinition = import("./hooks/use-shopping-cart-add.js").TShoppingCartAddServices>({ service, options, }: {
        service: new () => SVC_8;
        options?: import("./hooks/use-shopping-cart-add.js").IUseShoppingCartAdd<SVC_8> | undefined;
    }) => ({ callOptions, createNewOrderWhen, orderType, payload, hookCallOptions, }: {
        callOptions?: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions | undefined;
        createNewOrderWhen?: "completed" | "paid" | undefined;
        orderType: EVA.Core.OrderTypes;
        payload: Omit<SVC_8["request"], "OrderID" | "SessionID" | "TargetOrderID">;
        hookCallOptions?: import("./hooks/use-shopping-cart-add.js").IUseShoppingCartAddHookOptions | undefined;
    }) => Promise<SVC_8["response"] | undefined>;
    useShoppingCartClear: () => () => Promise<void>;
    useShoppingCartModify: <SVC_9 extends import("@springtree/eva-services-core").IEvaServiceDefinition = import("./hooks/use-shopping-cart-modify.js").TShoppingCartModifyingServices>({ service, options, }: {
        service: new () => SVC_9;
        options?: import("./hooks/use-shopping-cart-modify.js").IUseShoppingCartModifyOptions<SVC_9> | undefined;
    }) => ({ payload, callOptions, hookCallOptions, }: {
        payload: Partial<SVC_9["request"]>;
        callOptions?: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions | undefined;
        hookCallOptions?: import("./hooks/use-shopping-cart-modify.js").IUseShoppingCartModifyHookOptions | undefined;
    }) => Promise<SVC_9["response"] | undefined>;
    useSwitchOrganizationUnit: () => (newOrganizationUnitID: number) => Promise<void>;
};
export declare const builders: {
    buildAnonymousServiceState: <SVC extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ allowEmptyRequest, service, defaultRequest, key, beforeRequest, customRequest, requestedOrganizationUnitIDOverrideState, }: {
        allowEmptyRequest?: boolean | undefined;
        service: new () => SVC;
        defaultRequest?: SVC["request"] | undefined;
        key?: string | undefined;
        beforeRequest?: ((params: {
            req: SVC["request"];
            get: import("recoil").GetRecoilValue;
        }) => SVC["request"]) | undefined;
        customRequest?: ((params: {
            endpoint: import("@springtree/eva-sdk-core-service").EvaEndpoint;
            payload?: SVC["request"] | undefined;
            options: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions;
        }) => Promise<SVC["response"]>) | undefined;
        requestedOrganizationUnitIDOverrideState?: import("recoil").RecoilState<number> | undefined;
    }) => import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<SVC>;
    buildServiceFamilyState: <SVC_1 extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ allowEmptyRequest, service, defaultRequest, key, requireCustomer, requireEmployee, requireLoggedIn, beforeRequest, customRequest, requestedOrganizationUnitIDOverrideState, }: {
        allowEmptyRequest?: boolean | undefined;
        service: new () => SVC_1;
        defaultRequest?: SVC_1["request"] | undefined;
        key?: string | undefined;
        requireCustomer?: boolean | undefined;
        requireEmployee?: boolean | undefined;
        requireLoggedIn?: boolean | undefined;
        beforeRequest?: ((params: {
            req: SVC_1["request"];
            get: import("recoil").GetRecoilValue;
            parameter: import("recoil").SerializableParam;
        }) => SVC_1["request"]) | undefined;
        customRequest?: ((params: {
            endpoint: import("@springtree/eva-sdk-core-service").EvaEndpoint;
            payload?: SVC_1["request"] | undefined;
            options: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions;
        }) => Promise<SVC_1["response"]>) | undefined;
        requestedOrganizationUnitIDOverrideState?: import("recoil").RecoilState<number> | undefined;
    }) => import("./builders/build-service-family-state.js").IServiceFamilyState<SVC_1>;
    buildServiceState: <SVC_2 extends import("@springtree/eva-services-core").IEvaServiceDefinition>({ allowEmptyRequest, service, defaultRequest, key, requireCustomer, requireEmployee, requireLoggedIn, beforeRequest, customRequest, requestedOrganizationUnitIDOverrideState, }: {
        allowEmptyRequest?: boolean | undefined;
        service: new () => SVC_2;
        defaultRequest?: SVC_2["request"] | undefined;
        key?: string | undefined;
        requireCustomer?: boolean | undefined;
        requireEmployee?: boolean | undefined;
        requireLoggedIn?: boolean | undefined;
        beforeRequest?: ((params: {
            req: SVC_2["request"];
            get: import("recoil").GetRecoilValue;
        }) => SVC_2["request"]) | undefined;
        customRequest?: ((params: {
            endpoint: import("@springtree/eva-sdk-core-service").EvaEndpoint;
            payload?: SVC_2["request"] | undefined;
            options: import("@springtree/eva-sdk-core-service").IEvaServiceCallOptions;
        }) => Promise<SVC_2["response"]>) | undefined;
        requestedOrganizationUnitIDOverrideState?: import("recoil").RecoilState<number> | undefined;
    }) => import("./builders/build-service-state.js").IServiceState<SVC_2>;
};
export { EvaRecoilRoot, IUserExpiredCallbackParameters } from './eva-recoil-root.js';
export declare const state: {
    admin: {
        adminModuleListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-admin").Admin.AdminGetAllModules>;
    };
    checkout: {
        shoppingCartProductCountState: import("recoil").RecoilValueReadOnly<productCount.IProductCountByType | undefined>;
        shoppingCartState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetShoppingCart>;
        shoppingCartStatusState: import("recoil").RecoilValueReadOnly<orderStatus.IOrderStatus | undefined>;
    };
    core: {
        applicationConfigurationState: import("recoil").RecoilValueReadOnly<EVA.Core.GetApplicationConfigurationResponse | undefined>;
        applicationTokenState: import("recoil").RecoilState<string | undefined>;
        evaEndpointUrlState: import("recoil").RecoilState<string>;
        pingState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.Ping>;
        requestedOrganizationUnitIdState: import("recoil").RecoilState<number | undefined>;
        requestedOrganizationUnitQueryState: import("recoil").RecoilState<{
            Name: string;
            BackendID: string;
        } | undefined>;
    };
    currentUser: {
        currentUserApplicationConfigurationState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetApplicationConfiguration>;
        currentUserAuthorizationStructureState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetAuthorizationStructure>;
        currentUserOrganizationUnitDetailsState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetOrganizationUnitDetailed>;
        currentUserState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetCurrentUser>;
        currentUserStationListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.ListStationsForOrganizationUnit>;
        currentUserTokenState: import("recoil").RecoilState<string>;
        currentUserTypeState: import("recoil").RecoilValueReadOnly<import("./state/current-user/current-user-type-state.js").IEvaCurrentUserType>;
    };
    customer: {
        customerOrderListDetailsState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetOrder>;
        customerOrderListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.ListOrdersForCustomer>;
    };
    order: {
        orderDetailsProductCountState: import("recoil").RecoilValueReadOnly<productCount.IProductCountByType | undefined>;
        orderDetailsState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetOrder>;
        orderDetailsStatusState: import("recoil").RecoilValueReadOnly<orderStatus.IOrderStatus | undefined>;
        orderListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.SearchOrders>;
    };
    organizationUnit: {
        listOrganizationUnitsState: import("./builders/build-anonymous-service-state.js").IAnonymousServiceState<import("@springtree/eva-services-core").Core.ListOrganizationUnitSummaries>;
    };
    product: {
        productBundleListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.ListProductBundles>;
        productDetailAvailabilityState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductAvailability>;
        productDetailBundleAvailabilityState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductAvailability>;
        productDetailBundleState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetBundleProductDetails>;
        productDetailConfigurableAvailabilityState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductAvailability>;
        productDetailConfigurableState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetConfigurableProductDetail>;
        productDetailProductPricesState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductPrices>;
        productDetailState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductDetail>;
        productListState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.SearchProducts>;
        productListAvailabilityState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductAvailability>;
        productListPricesState: import("./builders/build-service-state.js").IServiceState<import("@springtree/eva-services-core").Core.GetProductPrices>;
    };
};
//# sourceMappingURL=eva-sdk-react-recoil.d.ts.map