/**
 * Helper method to extract all the roles a user has
 *
 * @param {EVA.Core.GetAuthorizationStructureResponse} authorizationStructure
 * @returns {{ ID: number, Name: string }}
 */
export declare const getRoles: ({ authorizationStructure, }: {
    authorizationStructure: EVA.Core.GetAuthorizationStructureResponse;
}) => {
    ID: number;
    Name: string;
}[];
/**
 * Returns all the roles that match for a given functionality
 * and type (scope or elevated). Optionally targeting a specific organization unit.
 *
 * @param {({
 *   authorizationStructure: EVA.Core.GetAuthorizationStructureResponse,
 *   organizationUnitId?: number,
 *   functionality: string,
 *   scope: EVA.Core.FunctionalityScope,
 *   type: 'elevated'|'scoped',
 * })} {
 *   authorizationStructure,
 *   organizationUnitId,
 *   functionality,
 *   scope,
 *   type = 'scoped',
 * }
 * @returns
 */
export declare const getMatchingRoles: ({ authorizationStructure, organizationUnitId, functionality, scope, type, }: {
    authorizationStructure: EVA.Core.GetAuthorizationStructureResponse;
    organizationUnitId?: number;
    functionality: string;
    scope: EVA.Core.FunctionalityScope;
    type?: 'elevated' | 'scoped';
}) => EVA.Core.RoleWithFunctionalitiesAndOrganizationUnits[];
/**
 * Returns if there is any matching role for a given functionality
 * and type (scope or elevated). Optionally targeting a specific organization unit.
 *
 * @param {({
 *   authorizationStructure: EVA.Core.GetAuthorizationStructureResponse,
 *   organizationUnitId?: number,
 *   functionality: string,
 *   scope: EVA.Core.FunctionalityScope,
 *   type: 'elevated'|'scoped',
 * })} {
 *   authorizationStructure,
 *   organizationUnitId,
 *   functionality,
 *   scope,
 *   type = 'scoped',
 * }
 * @returns {boolean}
 */
export declare const hasFunctionality: ({ authorizationStructure, organizationUnitId, functionality, scope, type, }: {
    authorizationStructure: EVA.Core.GetAuthorizationStructureResponse;
    organizationUnitId?: number;
    functionality: string;
    scope: EVA.Core.FunctionalityScope;
    type?: 'elevated' | 'scoped';
}) => boolean;
//# sourceMappingURL=authorization-structure.d.ts.map