export type TUserTokenExpiredCallback = (userToken: string) => void;
/**
 * Helper class that works on the observer principle to notify a user token
 * has expired. Used in the context to provide an expiration callback to React
 *
 * @class UserExpiration
 */
export declare class UserExpiration {
    /**
     * The array of callbacks that are subscribed to user token expirations
     *
     * @private
     */
    private callbacks;
    /**
     * Remember the last emitted token to prevent rapid firing the same token.
     * Quite common when a cluster of services was queued.
     *
     * @private
     * @type {string}
     */
    private lastToken;
    /**
     * Add a callback to receive expired tokens
     *
     * @param {TUserTokenExpiredCallback} callback
     */
    subscribe(callback: TUserTokenExpiredCallback): void;
    /**
     * Remove a callback to stop receiving expired user tokens
     *
     * @param {TUserTokenExpiredCallback} callback
     */
    unsubscribe(callback: TUserTokenExpiredCallback): void;
    /**
     * Notify a user token has expired
     *
     * @param {string} userToken
     * @returns
     */
    tokenExpired(userToken: string): void;
}
declare const userExpiration: UserExpiration;
export default userExpiration;
//# sourceMappingURL=user-expiration.d.ts.map