import { IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
import { IEvaServiceDefinition } from '@springtree/eva-services-core';
/**
 * These are the options for the hook itself
 * Not to be confused with the callOptions for the EVA service call.
 *
 * @interface IUseCallServiceOptions
 * @template SVC
 */
export interface IUseCallServiceOptions<SVC extends IEvaServiceDefinition> {
    onSuccess?: (data: SVC['response']) => void;
    onError?: (error: Error) => void;
}
/**
 * This hook is a convenience for calling services on an EVA endpoint with
 * the current endpoint and user token from the recoil state.
 *
 * @template SVC
 * @param {new() => SVC} service The service to call
 * @returns
 */
declare const useCallService: <SVC extends IEvaServiceDefinition>({ service, }: {
    service: new () => SVC;
}) => (requestPayload?: SVC['request'], callOptions?: IEvaServiceCallOptions, hookOptions?: IUseCallServiceOptions<SVC>) => Promise<SVC["response"] | undefined>;
export default useCallService;
//# sourceMappingURL=use-call-service.d.ts.map