import { IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
import { Core, IEvaServiceDefinition } from '@springtree/eva-services-core';
/**
 * These are the options for the hook itself
 * Not to be confused with the callOptions for the EVA service call.
 *
 * @interface IUseShoppingCartAdd
 * @template SVC
 */
export interface IUseShoppingCartAdd<SVC extends IEvaServiceDefinition> {
    onSuccess?: (data: SVC['response']) => void;
    onError?: (error: Error) => void;
}
export interface IUseShoppingCartAddHookOptions {
    /**
     * This can be useful when performing bulk order operations and manually marking the order stale when all calls have completed
     */
    doNotSetStale?: boolean;
}
export type TShoppingCartAddServices = Core.AddBundleProductToOrder | Core.AddDigitalGiftCardToOrder | Core.AddDiscountCouponToOrder | Core.AddManualDiscountToOrder | Core.AddProductToOrder | Core.AddServiceProductToOrder | Core.AddUserBorrowedProductToOrder | Core.CreateCustomer;
export declare const useShoppingCartAdd: <SVC extends IEvaServiceDefinition = TShoppingCartAddServices>({ service, options, }: {
    service: new () => SVC;
    options?: IUseShoppingCartAdd<SVC>;
}) => ({ callOptions, createNewOrderWhen, orderType, payload, hookCallOptions, }: {
    callOptions?: IEvaServiceCallOptions;
    createNewOrderWhen?: 'completed' | 'paid';
    orderType: EVA.Core.OrderTypes;
    payload: Omit<SVC['request'], 'OrderID' | 'SessionID' | 'TargetOrderID'>;
    hookCallOptions?: IUseShoppingCartAddHookOptions;
}) => Promise<SVC["response"] | undefined>;
export default useShoppingCartAdd;
//# sourceMappingURL=use-shopping-cart-add.d.ts.map