import { IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
import { Core, IEvaServiceDefinition } from '@springtree/eva-services-core';
/**
 * These are the options for the hook itself
 * Not to be confused with the callOptions for the EVA service call.
 *
 * @interface IUseShoppingCartModifyOptions
 * @template SVC
 */
export interface IUseShoppingCartModifyOptions<SVC extends IEvaServiceDefinition> {
    onSuccess?: (data: SVC['response']) => void;
    onError?: (error: Error) => void;
}
export interface IUseShoppingCartModifyHookOptions {
    /**
     * This can be useful when performing bulk order operations and manually marking the order stale when all calls have completed
     */
    doNotSetStale?: boolean;
}
export type TShoppingCartModifyingServices = Core.AttachCustomerToOrder | Core.AddDiscountCouponToOrder | Core.CancelDiscountOrderLine | Core.CancelOrder | Core.ChangeOrderLinesToCarryOut | Core.ChangeOrderLinesToDelivery | Core.ChangeOrderLinesToPickup | Core.CreateCustomer | Core.CreateOrderLineUnitPriceCorrection | Core.DetachCompanyFromUser | Core.Login | Core.ModifyOrderLinePrice | Core.ModifyQuantityOrdered | Core.PrepareOrderForCheckout | Core.RemoveOrderLineUnitPriceCorrection | Core.SetGiftWrappingOptionsOnOrder | Core.SetPickProductDiscountOptionsForOrderLine | Core.SetRequestedDate | Core.SplitOrderLine | Core.UpdateOrderAddresses | Core.UpdateOrderBillingAddress | Core.UpdateOrderCustomFields | Core.UpdateOrderShippingAddress | Core.UpdateProductRequirementValuesForOrderLine | Core.UpdateSerialNumber;
export declare const useShoppingCartModify: <SVC extends IEvaServiceDefinition = TShoppingCartModifyingServices>({ service, options, }: {
    service: new () => SVC;
    options?: IUseShoppingCartModifyOptions<SVC>;
}) => ({ payload, callOptions, hookCallOptions, }: {
    payload: Partial<SVC['request']>;
    callOptions?: IEvaServiceCallOptions;
    hookCallOptions?: IUseShoppingCartModifyHookOptions;
}) => Promise<SVC["response"] | undefined>;
export default useShoppingCartModify;
//# sourceMappingURL=use-shopping-cart-modify.d.ts.map