import { ISettingsChange } from '@springtree/eva-sdk-core-settings';
/**
 * The settings for the module
 *
 * @export
 * @interface IEvaReactRecoilSettings
 */
export interface IEvaReactRecoilSettings {
    /**
     * The default page size for services that support pagination
     *
     * @type {number}
     */
    defaultPageSize: number;
    /**
     * The limit specifically for the organization unit list state
     */
    organizationUnitListLimit: number;
    /**
     * The default included product properties for services such as:
     *
     * - Core.GetOrder
     * - Core.GetShoppingCart
     * - Core.SearchProducts
     * - Core.GetProducts
     * - Core.GetBundleProductDetails
     * - Core.ListProductBundles
     *
     * This is not an exhaustive list. In a service request these can be either
     * called IncludedFields or ProductProperties.
     *
     * @type {string[]}
     */
    defaultProductProperties: string[];
    /**
     * The additional request options for the shoppingCart state.
     * Defaults are set to retrieve the most logical data needed
     * before entering the checkout. Discounts, product requirements, etc.
     *
     * @type {EVA.Core.AdditionalOrderDataOptions}
     */
    shoppingCartOptions: EVA.Core.AdditionalOrderDataOptions;
    /**
     * The additional request options for the currentOrder state.
     * Defaults are set to retrieve the most logical data needed
     * during the checkout. Shipping methods, payment methods, etc.
     *
     * @type {EVA.Core.AdditionalOrderDataOptions}
     */
    currentOrderOptions: EVA.Core.AdditionalOrderDataOptions;
}
export declare const defaultProductProperties: string[];
export declare const SETTINGS_GROUP_NAME = "evaReactRecoil";
/**
 * Retrieves the settings for the EvaReactRecoil module
 *
 * @export
 * @returns {IEvaReactRecoilSettings}
 */
export declare function getReactRecoilSettings(): IEvaReactRecoilSettings;
/**
 * Changes a setting for the EvaReactRecoil module
 *
 * @export
 * @param {string} settingName
 * @param {*} setting
 * @returns {ISettingsChange}
 */
export declare function setReactRecoilSetting(settingName: keyof IEvaReactRecoilSettings, setting: IEvaReactRecoilSettings[keyof IEvaReactRecoilSettings]): ISettingsChange;
//# sourceMappingURL=settings.d.ts.map